@@ -3,8 +3,9 @@ from importlib import import_module as _import_module
 from . import typing
 from ._example import example_filepath
 from ._testit import test
+from .bin import binary_version
 from .domtbl import read_domtbl
-from .hmmer import HMMER
+from .hmmer import HMMER, SeqDB
 from .tbl import read_tbl
 
 try:
@@ -14,8 +15,10 @@ except ModuleNotFoundError:
 
 __all__ = [
     "HMMER",
+    "SeqDB",
     "__version__",
     "example_filepath",
+    "binary_version",
     "read_domtbl",
     "read_tbl",
     "test",
